@@ -1,18 +1,16 @@
 """Point data structure to represent LineProtocol."""
 
 import math
+import warnings
 from builtins import int
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from decimal import Decimal
 from numbers import Integral
 
-from pytz import UTC
-from six import iteritems
-
 from influxdb_client.client.util.date_utils import get_date_helper
 from influxdb_client.domain.write_precision import WritePrecision
 
-EPOCH = UTC.localize(datetime.utcfromtimestamp(0))
+EPOCH = datetime.utcfromtimestamp(0).replace(tzinfo=timezone.utc)
 
 DEFAULT_WRITE_PRECISION = WritePrecision.NS
 
@@ -50,7 +48,7 @@ class Point(object):
     """
     Point defines the values that will be written to the database.
 
-    Ref: http://bit.ly/influxdata-point
+    Ref: https://docs.influxdata.com/influxdb/latest/reference/key-concepts/data-elements/#point
     """
 
     @staticmethod
@@ -184,6 +182,13 @@ class Point(object):
          :param precision: required precision of LineProtocol. If it's not set then use the precision from ``Point``.
         """
         _measurement = _escape_key(self._name, _ESCAPE_MEASUREMENT)
+        if _measurement.startswith("#"):
+            message = f"""The measurement name '{_measurement}' start with '#'.
+
+The output Line protocol will be interpret as a comment by InfluxDB. For more info see:
+    - https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/#comments
+"""
+            warnings.warn(message, SyntaxWarning)
         _tags = _append_tags(self._tags)
         _fields = _append_fields(self._fields)
         if not _fields:
@@ -209,7 +214,7 @@ class Point(object):
 
 def _append_tags(tags):
     _return = []
-    for tag_key, tag_value in sorted(iteritems(tags)):
+    for tag_key, tag_value in sorted(tags.items()):
 
         if tag_value is None:
             continue
@@ -225,7 +230,7 @@ def _append_tags(tags):
 def _append_fields(fields):
     _return = []
 
-    for field, value in sorted(iteritems(fields)):
+    for field, value in sorted(fields.items()):
         if value is None:
             continue
 
@@ -252,26 +257,26 @@ def _append_fields(fields):
     return f"{','.join(_return)}"
 
 
-def _append_time(time, write_precision):
+def _append_time(time, write_precision) -> str:
     if time is None:
         return ''
     return f" {int(_convert_timestamp(time, write_precision))}"
 
 
-def _escape_key(tag, escape_list=None):
+def _escape_key(tag, escape_list=None) -> str:
     if escape_list is None:
         escape_list = _ESCAPE_KEY
     return str(tag).translate(escape_list)
 
 
-def _escape_tag_value(value):
+def _escape_tag_value(value) -> str:
     ret = _escape_key(value)
     if ret.endswith('\\'):
         ret += ' '
     return ret
 
 
-def _escape_string(value):
+def _escape_string(value) -> str:
     return str(value).translate(_ESCAPE_STRING)
 
 
