@@ -10,10 +10,10 @@ from random import random
 from time import sleep
 from typing import Union, Any, Iterable, NamedTuple
 
-import rx
-from rx import operators as ops, Observable
-from rx.scheduler import ThreadPoolScheduler
-from rx.subject import Subject
+import reactivex as rx
+from reactivex import operators as ops, Observable
+from reactivex.scheduler import ThreadPoolScheduler
+from reactivex.subject import Subject
 
 from influxdb_client import WritePrecision
 from influxdb_client.client._base import _BaseWriteApi, _HAS_DATACLASS
@@ -23,7 +23,7 @@ from influxdb_client.client.write.point import Point, DEFAULT_WRITE_PRECISION
 from influxdb_client.client.write.retry import WritesRetry
 from influxdb_client.rest import _UTF_8_encoding
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('influxdb_client.client.write_api')
 
 
 if _HAS_DATACLASS:
@@ -294,6 +294,10 @@ class WriteApi(_BaseWriteApi):
         :key data_frame_measurement_name: name of measurement for writing Pandas DataFrame - ``DataFrame``
         :key data_frame_tag_columns: list of DataFrame columns which are tags,
                                      rest columns will be fields - ``DataFrame``
+        :key data_frame_timestamp_column: name of DataFrame column which contains a timestamp. The column can be defined as a :class:`~str` value
+                                          formatted as `2018-10-26`, `2018-10-26 12:00`, `2018-10-26 12:00:00-05:00`
+                                          or other formats and types supported by `pandas.to_datetime <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.to_datetime.html#pandas.to_datetime>`_ - ``DataFrame``
+        :key data_frame_timestamp_timezone: name of the timezone which is used for timestamp column - ``DataFrame``
         :key record_measurement_key: key of record with specified measurement -
                                      ``dictionary``, ``NamedTuple``, ``dataclass``
         :key record_measurement_name: static measurement name - ``dictionary``, ``NamedTuple``, ``dataclass``
@@ -322,8 +326,8 @@ class WriteApi(_BaseWriteApi):
                 write_api.write("my-bucket", "my-org", point)
 
         DataFrame:
-            The index of `Pandas DataFrame <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.html>`_
-            is used as a ``timestamp`` for written data. The index should be `PeriodIndex <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.PeriodIndex.html#pandas.PeriodIndex>`_
+            If the ``data_frame_timestamp_column`` is not specified the index of `Pandas DataFrame <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.html>`_
+            is used as a ``timestamp`` for written data. The index can be `PeriodIndex <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.PeriodIndex.html#pandas.PeriodIndex>`_
             or its must be transformable to ``datetime`` by
             `pandas.to_datetime <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.to_datetime.html#pandas.to_datetime>`_.
 
